//
//  WebViewController.swift
//  GeliBusinessPlatform
//
//  Created by 刘俊宏 on 2020/4/28.
//  Copyright © 2020 junye lu. All rights reserved.
//

import UIKit
import WebKit

class WebViewController: BaseViewController {
    // wkWebView
    lazy var wkWebView = WKWebView()
    // 进度条
    lazy var progressView = UIProgressView()
    override func viewDidLoad() {
        super.viewDidLoad()
        
        navbar.title = ""
        self.view.addSubview(navbar)
        
        initInterface()
        
    }
    var loadHTMLString:String? = ""
    var urlStr:String? = ""
    var isAddObserver = false
    func initInterface() -> () {
        
        if urlStr?.count == 0 && loadHTMLString?.count != 0{
            
            let headerString : String = "<header><meta name='viewport' content='width=device-width, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0, user-scalable=no'><style>img{max-width:100%}</style></header>"
            
            wkWebView.loadHTMLString(loadHTMLString! + headerString, baseURL: nil)
        }else {
            let url = URL(string: urlStr!)
            let request = URLRequest.init(url: url!, cachePolicy: .reloadRevalidatingCacheData, timeoutInterval: 10)

            wkWebView.load(request)
        }
        isAddObserver = true
        wkWebView.navigationDelegate = self
        
        self.view.addSubview(self.wkWebView)
        self.wkWebView.snp.makeConstraints { (make) in
            make.left.bottom.right.equalTo(0)
            make.top.equalTo(navbar.snp.bottom)
        }
        wkWebView.addObserver(self, forKeyPath: "estimatedProgress", options: .new, context: nil)
        
        progressView.progressTintColor = UIColor.init(named: "蓝色字体颜色")
        progressView.trackTintColor = UIColor.clear
        self.view.addSubview(self.progressView)
        progressView.snp.makeConstraints { (make) in
            make.left.right.equalTo(0)
            make.top.equalTo(navbar.snp.bottom)
            make.height.equalTo(2)
        }

    }
    deinit {
        print("con is deinit")
        if isAddObserver {
            wkWebView.removeObserver(self, forKeyPath: "estimatedProgress")
        }
     }
}
extension WebViewController: WKNavigationDelegate
{
    
    // 监听网页加载进度
    override func observeValue(forKeyPath keyPath: String?, of object: Any?, change: [NSKeyValueChangeKey : Any]?, context: UnsafeMutableRawPointer?) {
        print("进度=\(self.wkWebView.estimatedProgress)")
        progressView.setProgress(Float(self.wkWebView.estimatedProgress), animated: true)

    }
    
    // 页面开始加载时调用
    func webView(_ webView: WKWebView, didStartProvisionalNavigation navigation: WKNavigation!) {
        print("开始加载...")
        progressView.setProgress(Float(0.2), animated: true)
 
//        Log4jMessage(message: "开始加载...")
    }
    
    // 当内容开始返回时调用
    func webView(_ webView: WKWebView, didCommit navigation: WKNavigation!){
        print("当内容开始返回...")
        progressView.setProgress(Float(0.7), animated: true)
//        Log4jMessage(message: "当内容开始返回...")
    }
    
    // 页面加载完成之后调用
    func webView(_ webView: WKWebView, didFinish navigation: WKNavigation!){
//        Log4jMessage(message: "页面加载完成...")
        print("页面加载完成...")

        /// 获取网页title
        navbar.title = self.wkWebView.title
        
        UIView.animate(withDuration: 0.5) {
            self.progressView.isHidden = true
        }
    }
    
    // 页面加载失败时调用
    func webView(_ webView: WKWebView, didFail navigation: WKNavigation!, withError error: Error){
//        Log4jMessage(message: "页面加载失败...")
        print("页面加载失败...")

        UIView.animate(withDuration: 0.5) {
            self.progressView.progress = 0.0
            self.progressView.isHidden = true
        }
        /// 弹出提示框点击确定返回
        let alertView = UIAlertController.init(title: "提示", message: "加载失败", preferredStyle: .alert)
        let okAction = UIAlertAction.init(title:"确定", style: .default) { okAction in
            _=self.navigationController?.popViewController(animated: true)
        }
        alertView.addAction(okAction)
        self.present(alertView, animated: true, completion: nil)
    }

}
